@@ -8,7 +8,7 @@ tvp <- function(y,x,V,lambda,W=NULL,kappa=NULL,c=NULL)
 
 ### x - a matrix of independent variables (drivers), different columns correspond to different variables
 
-### V - initial variance in the state space equation for the recursive moment estimator updating method, 
+### V - initial variance in the state space equation for the recursive moment estimator updating method,
 ###     as in the paper by Raftery et al. (2010),
 
 ### lambda - a forgetting factor between 0 and 1 used in variance approximations
@@ -23,12 +23,9 @@ tvp <- function(y,x,V,lambda,W=NULL,kappa=NULL,c=NULL)
 
 ### c - a parameter indicating whether constant is included,
 ###     by default c=TRUE (constant is included),
-###     it is not possible to set c=FALSE if ncol(x)=0 
+###     it is not possible to set c=FALSE if ncol(x)=0
 
 
-requireNamespace('xts')
-requireNamespace('stats')
-
 if ( is.null(c) ) { c <- TRUE }
 
 x <- as.matrix(x)
@@ -73,15 +70,15 @@ if (is.null(W))
       for (i in 1:ncol(x))
         {
           v[i] <- var(x[,i])
-          if (v[i]==0) { v[i] <- 0.0001 }
+          if (v[i]==0) { v[i] <- 0.001 * (1/(2^ncol(x))) }
         }
     }
   if (length(y)>1)
     {
       vary <- as.numeric(var(as.numeric(y)))
     }
-  
-  if (ncol(x)>0 && length(y)>1) 
+
+  if (ncol(x)>0 && length(y)>1)
     {
       for (j in 1:length(v))
         {
@@ -108,9 +105,9 @@ if (!is.null(W))
 #########################
 #########################
 
-if (c == FALSE) 
-  { 
-    xe <- xe[,-1,drop=FALSE] 
+if (c == FALSE)
+  {
+    xe <- xe[,-1,drop=FALSE]
     E <- E[-1,-1]
   }
 
@@ -120,12 +117,12 @@ thetas <- tvpcppout[[1]]
 y.tvp <- tvpcppout[[2]]
 pdensi <- tvpcppout[[3]]
 
-thetas <- t(thetas[,-1])
-if (!is.null(colnames(x))) 
-  { 
-    if ( c == TRUE ) 
+thetas <- t(thetas[,-ncol(thetas)])
+if (!is.null(colnames(x)))
+  {
+    if ( c == TRUE )
       {
-        colnames(thetas) <- c("const",colnames(x)) 
+        colnames(thetas) <- c("const",colnames(x))
       }
     else
       {
@@ -134,11 +131,12 @@ if (!is.null(colnames(x)))
       }
   }
 if (ncol(x)==0)
-  { 
-    thetas <- t(thetas) 
+  {
+    thetas <- t(thetas)
     colnames(thetas) <- "const"
   }
 
+y.tvp <- as.vector(y.tvp)
 ret <- list(y.tvp,thetas,pdensi,as.matrix(y))
 names(ret) <- c("y.hat","thetas","pred.dens.","y")
 class(ret) <- "tvp"
